/*
 * File:   I_AN
 * Author: Bart Huyskens - www.e2cre8.be  04/2016
 * HARDWARE: BRAINBOX FUN - PIC18F445 + Bootloader running at 48Mhz
 * 
 * This program 'reads' the analog voltage at pin AN0
 * The 8 bit result is displayed at the 8 leds of PORTD
 * Connect a potmeter to AN0 (between 5V and GND)
 * The 4 analog input pins of the Brainbox Fun are configured as AD input 
 */
// PIC18F4455 Configuration Bit Settings - 
// all config settings are made in the bootloader

#include <xc.h>   // general XC8 library
#define _XTAL_FREQ 48000000  // Brainbox Fun running at 48Mhz

#define LEDARRAY PORTD    // using a define to give pin a better name


void main(void) // main program
{  
    //alle these settings are well explained in the datasheet of the 18F4455
    TRISD = 0x00;           // make all 8 nits of PORTD output - LEDS
    
    TRISAbits.RA0 = 1;      // make pin INPUT pin
    TRISAbits.RA1 = 1;      // make pin INPUT pin
    TRISAbits.RA2 = 1;      // make pin INPUT pin
    TRISAbits.RA3 = 1;      // make pin INPUT pin
    
    ADCON2bits.ADFM = 0;    // 0 = Left justified -> 8 bit adc
    ADCON2bits.ACQT2 = 1;
    ADCON2bits.ACQT1 = 1;
    ADCON2bits.ACQT0 = 1;   // 111 = Aquisition time of 20 TAD - slowest
    ADCON2bits.ADCS2 = 1;
    ADCON2bits.ADCS2 = 1;
    ADCON2bits.ADCS2 = 1;   // FOSC/64 is necessary for our fast 48Mhz clock
    
    ADCON1bits.VCFG1 = 0;   // REF- = VSS
    ADCON1bits.VCFG0 = 0;   // REF+ = VDD
    ADCON1bits.PCFG3 = 1; 
    ADCON1bits.PCFG2 = 0; 
    ADCON1bits.PCFG1 = 1; 
    ADCON1bits.PCFG0 = 1;   //1011 makes pins AN0, AN1, AN2, AN3 all analog input pins
                            // all other AD pins are normal digital IO pins
    
    ADCON0bits.CHS3 = 0; 
    ADCON0bits.CHS2 = 0; 
    ADCON0bits.CHS1 = 0; 
    ADCON0bits.CHS0 = 0;    // 0000 = Select Channel AN0 for AD conversion
    ADCON0bits.ADON = 1;    // switch AD convertor on
    
    
    while(1)
        { // never ending loop
        ADCON0bits.GODONE = 1;  // Start AD conversion
        while (GODONE){}        // wait for AD conversion to complete
        LEDARRAY = ADRESH;      // show 8 bit AD result on LEDS of portD
        }
}

